<?php
class ControllerExtensionPaymentGateWay extends Controller {
	public function index() {
		$this->load->language('extension/payment/gateway');
		
		return $this->load->view('extension/payment/gateway', $data);
	}

	public function confirm() {

	    $this->load->language('extension/payment/gateway');

		$this->load->model('checkout/order');
		$order_info = $this->model_checkout_order->getOrder($this->session->data['order_id']);

		$data['return'] = $this->url->link('checkout/success', '', 'SSL');
		$data['cancel_return'] = $this->url->link('checkout/payment', '', 'SSL');
		$data['back'] = $this->url->link('checkout/payment', '', 'SSL');

		$amount   = $this->currency->format($order_info['total'], $order_info['currency_code'], false, false);
		$amount = $this->currency->convert($amount, $order_info['currency_code'], "TOM")*10;

		$data['comment'] 	  = empty($order_info['comment']) ? $this->language->get('text_user_no_comment') :$this->language->get('text_user_comment')." ".$order_info['comment'];
		$json = array();
		try 
		{
			$mg = new GateWay();
			$params = array(
				'merchantCode' 	=> $this->config->get('payment_gateway_merchant'),
				'amount' 		=> $amount,
				'callBackUrl' 	=> $this->url->link('extension/payment/gateway/callback', '', 'SSL'),
				'invoiceNumber' => $order_info['order_id'],
				'payerEmail'	=> (strlen($order_info['email']) ? $order_info['email'] : ''),
			);
			$request = $mg->paymentRequest($params);
			if ($request['status']) {
				$json['success'] = 'http://behbank.com/payment/'.$request['paymentNumber'];
			} else {
				$json['error'] = $request['message'];
			}
		}
		catch (Exception $e) 
		{
			$json['error'] = $this->language->get('error_connection');
		}
		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));		
	}

	public function callback() {
		if ($this->session->data['payment_method']['code'] == 'gateway') {
			$this->load->language('extension/payment/gateway');

			$data['results'] = "";

			$order_id = !empty($this->session->data['order_id']) ? $this->session->data['order_id'] : 0;

			$this->load->model('checkout/order');
			$order_info = $this->model_checkout_order->getOrder($order_id);

			if($order_info) {
				$gatewayStatus = isset($this->request->post['status']) ? $this->request->post['status'] : false;
				$gatewayPaymentNumber = isset($this->request->post['paymentNumber']) ? $this->request->post['paymentNumber'] : false;
				if($gatewayStatus && $gatewayPaymentNumber)
				{
					$mg = new GateWay();
					$params = array(
						'merchantCode' => $this->config->get('payment_gateway_merchant'),
						'paymentNumber' => $gatewayPaymentNumber,
					);
					$request = $mg->paymentVerify($params);
						
					if($request['status'])
					{
						$comment = $this->language->get('text_payment_success')." ".$this->language->get('text_results') . $gatewayPaymentNumber;
						$this->model_checkout_order->addOrderHistory($order_id, $this->config->get('payment_gateway_order_status_id'), $comment, true);

                        $this->session->data['error_warning'] = NULL;
                        $this->session->data['success'] = $comment;
                        $this->session->data['results'] = $gatewayPaymentNumber;
					}
					else
					{
					    $this->session->data['error_warning'] = strlen($request['message']) ? $request['message'] : $this->language->get('error_connection');
                        $this->session->data['success'] = NULL;
					}			
				}
				else
				{
					$this->session->data['error_warning'] =  $this->language->get('error_no_paid');
                    $this->session->data['success'] = NULL;
				}
			}
			else 
			{
				$this->session->data['error_warning'] = $this->language->get('error_order_id');
                $this->session->data['success'] = NULL;
			}

            if ($this->session->data['success']) {
                $this->response->redirect($this->url->link('checkout/success', '', true));
            } else {
                $this->response->redirect($this->url->link('checkout/cart', '', true));
            } 
		}
	}
}

class GateWay {

	private $apiUrl = 'http://behbank.com/ws';

	private $gatewayUrl = 'http://behbank.com/payment';

	public function paymentRequest($params) {
		$curl = curl_init();
		curl_setopt($curl, CURLOPT_URL, $this->apiUrl.'/payments/request.json');
		curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type' => 'application/json'));
		curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($params));
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
		$response = json_decode(curl_exec($curl));
		curl_close($curl);
		if(isset($response->status) && $response->status == 1 ){
			return array(
				'status'    		=>  true,
				'paymentNumber'     =>  $response->paymentNumber,
			);
		}else{
			return array(
				'status'    =>  false,
				'message'   =>  $response->message,
			);
		}
	}

	public function paymentVerify($params) {
		$curl = curl_init();
		curl_setopt($curl, CURLOPT_URL, $this->apiUrl.'/payments/verify.json');
		curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type' => 'application/json'));
		curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode( $params ));
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
		$response = json_decode(curl_exec($curl));
		curl_close($curl);
		if(isset($response->status) && $response->status == 1){
			return array(
				'status'    =>  true,
			);
		}else{
			return array(
				'status'    =>  false,
				'message'   =>  $response->message,
			);
		}
	}

	public function getGatewayUrl() {
		return $this->gatewayUrl;
	}
}
?>